@@ -33,13 +33,13 @@ if you want to run it as a service user simplevisor-control as init script.
 
 Author: Massimo.Paladin@gmail.com
 
-Copyright (C) 2013 CERN
+Copyright (C) CERN 2013-2014
 """
 
 AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
-COPYRIGHT = "Copyright (C) 2013 CERN"
-VERSION = "0.8"
-DATE = "26 Apr 2013"
+COPYRIGHT = "Copyright (C) CERN 2013-2014"
+VERSION = "0.9"
+DATE = "27 Feb 2013"
 __author__ = AUTHOR
 __version__ = VERSION
 __date__ = DATE
